import matplotlib.pyplot as plt

class CorePlot():
    def __init__(self):
        self.fig = plt.figure(figsize=(5,3))

    def __enter__(self):
        return(self)

    def __exit__(self, exc_type, exc_value, exc_traceback):
        plt.show()


def plot(ax_func):
    cp = CorePlot()
    ax = cp.fig.add_subplot(111)

    ax = ax_func(ax)
        
    cp.ax = ax
    return cp


def multiplot(ax_funcs, indices):
    cp = CorePlot()
    axes = []
    
    for func, index in zip(ax_funcs, indices):
        ax = cp.fig.add_subplot(index)
        ax = func(ax)
        axes.append(ax)
        
    cp.axes = axes
    return cp


def set_ax(xlim:list[float]):
    
    def _set_ax(ax):
        ax.set_xlim(*xlim)
        return ax

    return _set_ax


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['necoplot']

package_data = \
{'': ['*']}

install_requires = \
['japanize-matplotlib>=1.1.3,<2.0.0', 'matplotlib>=3.5.1,<4.0.0']

setup_kwargs = {
    'name': 'necoplot',
    'version': '0.1.1',
    'description': 'Make it easier to plot by matplotlib',
    'long_description': '# necoplot\nunder development',
    'author': 'guneco',
    'author_email': 'gu3fav@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/guneco',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<3.11',
}


setup(**setup_kwargs)
